# API reference: core objects

Core objects define the main data structures used by FoodSpec. For workflow examples, see the User Guide and Workflows (e.g., Oil authentication, Hyperspectral analysis).

## FoodSpectrumSet

::: foodspec.core.dataset.FoodSpectrumSet

## HyperSpectralCube

::: foodspec.core.hyperspectral.HyperSpectralCube
> **Status:** Archived  
> This page has been superseded by the unified API reference. See [api_reference.md](api_reference.md#core-data-structures) for current core data structure APIs.
